# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/v1_12/auth/auth.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/v1_12/auth/auth.proto',
  package='auth_1_12',
  syntax='proto3',
  serialized_options=b'Z:github.com/pachyderm/pachyderm/src/client/admin/v1_12/auth',
  serialized_pb=b'\n\"client/admin/v1_12/auth/auth.proto\x12\tauth_1_12\x1a\x1fgoogle/protobuf/timestamp.proto\"L\n\x0f\x41\x63tivateRequest\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x14\n\x0cgithub_token\x18\x01 \x01(\t\x12\x12\n\nroot_token\x18\x03 \x01(\t\"&\n\x10\x41\x63tivateResponse\x12\x12\n\npach_token\x18\x01 \x01(\t\"\x13\n\x11\x44\x65\x61\x63tivateRequest\"\x14\n\x12\x44\x65\x61\x63tivateResponse\"\xc5\x03\n\nIDProvider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x04saml\x18\x03 \x01(\x0b\x32!.auth_1_12.IDProvider.SAMLOptions\x12/\n\x04oidc\x18\x05 \x01(\x0b\x32!.auth_1_12.IDProvider.OIDCOptions\x12\x33\n\x06github\x18\x04 \x01(\x0b\x32#.auth_1_12.IDProvider.GitHubOptions\x1aR\n\x0bSAMLOptions\x12\x14\n\x0cmetadata_url\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_xml\x18\x02 \x01(\x0c\x12\x17\n\x0fgroup_attribute\x18\x03 \x01(\t\x1a\x97\x01\n\x0bOIDCOptions\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x19\n\x11\x61\x64\x64itional_scopes\x18\x05 \x03(\t\x12\x1d\n\x15ignore_email_verified\x18\x06 \x01(\x08\x1a\x0f\n\rGitHubOptions\"\x9a\x02\n\nAuthConfig\x12\x1b\n\x13live_config_version\x18\x01 \x01(\x03\x12+\n\x0cid_providers\x18\x02 \x03(\x0b\x32\x15.auth_1_12.IDProvider\x12\x42\n\x10saml_svc_options\x18\x03 \x01(\x0b\x32(.auth_1_12.AuthConfig.SAMLServiceOptions\x1a~\n\x12SAMLServiceOptions\x12\x0f\n\x07\x61\x63s_url\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61sh_url\x18\x03 \x01(\t\x12\x18\n\x10session_duration\x18\x04 \x01(\t\x12\x15\n\rdebug_logging\x18\x05 \x01(\x08\"\x19\n\x17GetConfigurationRequest\"H\n\x18GetConfigurationResponse\x12,\n\rconfiguration\x18\x01 \x01(\x0b\x32\x15.auth_1_12.AuthConfig\"G\n\x17SetConfigurationRequest\x12,\n\rconfiguration\x18\x01 \x01(\x0b\x32\x15.auth_1_12.AuthConfig\"\x1a\n\x18SetConfigurationResponse\"5\n\x0c\x43lusterRoles\x12%\n\x05roles\x18\x01 \x03(\x0e\x32\x16.auth_1_12.ClusterRole\"\x1f\n\x1dGetClusterRoleBindingsRequest\"\xb5\x01\n\x1eGetClusterRoleBindingsResponse\x12I\n\x08\x62indings\x18\x01 \x03(\x0b\x32\x37.auth_1_12.GetClusterRoleBindingsResponse.BindingsEntry\x1aH\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.auth_1_12.ClusterRoles:\x02\x38\x01\"\\\n\x1fModifyClusterRoleBindingRequest\x12\x11\n\tprincipal\x18\x01 \x01(\t\x12&\n\x05roles\x18\x02 \x01(\x0b\x32\x17.auth_1_12.ClusterRoles\"\"\n ModifyClusterRoleBindingResponse\"\x12\n\x10GetAdminsRequest\"#\n\x11GetAdminsResponse\x12\x0e\n\x06\x61\x64mins\x18\x01 \x03(\t\"2\n\x13ModifyAdminsRequest\x12\x0b\n\x03\x61\x64\x64\x18\x01 \x03(\t\x12\x0e\n\x06remove\x18\x02 \x03(\t\"\x16\n\x14ModifyAdminsResponse\"R\n\x07OTPInfo\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x36\n\x12session_expiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x01\n\tTokenInfo\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x30\n\x06source\x18\x02 \x01(\x0e\x32 .auth_1_12.TokenInfo.TokenSource\";\n\x0bTokenSource\x12\x0b\n\x07INVALID\x10\x00\x12\x10\n\x0c\x41UTHENTICATE\x10\x01\x12\r\n\tGET_TOKEN\x10\x02\"l\n\x13\x41uthenticateRequest\x12\x14\n\x0cgithub_token\x18\x01 \x01(\t\x12\x12\n\noidc_state\x18\x03 \x01(\t\x12\x19\n\x11one_time_password\x18\x02 \x01(\t\x12\x10\n\x08id_token\x18\x04 \x01(\t\"*\n\x14\x41uthenticateResponse\x12\x12\n\npach_token\x18\x01 \x01(\t\"\x0f\n\rWhoAmIRequest\"q\n\x0eWhoAmIResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08is_admin\x18\x02 \x01(\x08\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\x12.\n\rcluster_roles\x18\x04 \x01(\x0b\x32\x17.auth_1_12.ClusterRoles\"u\n\x03\x41\x43L\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.auth_1_12.ACL.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0e\x32\x10.auth_1_12.Scope:\x02\x38\x01\"m\n\x05Users\x12\x32\n\tusernames\x18\x01 \x03(\x0b\x32\x1f.auth_1_12.Users.UsernamesEntry\x1a\x30\n\x0eUsernamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"f\n\x06Groups\x12-\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.auth_1_12.Groups.GroupsEntry\x1a-\n\x0bGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"A\n\x10\x41uthorizeRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\x12\x1f\n\x05scope\x18\x02 \x01(\x0e\x32\x10.auth_1_12.Scope\"\'\n\x11\x41uthorizeResponse\x12\x12\n\nauthorized\x18\x01 \x01(\x08\"2\n\x0fGetScopeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05repos\x18\x02 \x03(\t\"4\n\x10GetScopeResponse\x12 \n\x06scopes\x18\x01 \x03(\x0e\x32\x10.auth_1_12.Scope\"R\n\x0fSetScopeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04repo\x18\x02 \x01(\t\x12\x1f\n\x05scope\x18\x03 \x01(\x0e\x32\x10.auth_1_12.Scope\"\x12\n\x10SetScopeResponse\"\x1d\n\rGetACLRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\"=\n\x08\x41\x43LEntry\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x1f\n\x05scope\x18\x02 \x01(\x0e\x32\x10.auth_1_12.Scope\"b\n\x0eGetACLResponse\x12$\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x13.auth_1_12.ACLEntry\x12*\n\rrobot_entries\x18\x02 \x03(\x0b\x32\x13.auth_1_12.ACLEntry\"C\n\rSetACLRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\x12$\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x13.auth_1_12.ACLEntry\"\x10\n\x0eSetACLResponse\"C\n\x0bSessionInfo\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x16\n\x0e\x63onversion_err\x18\x03 \x01(\x08\"\x15\n\x13GetOIDCLoginRequest\"8\n\x14GetOIDCLoginResponse\x12\x11\n\tlogin_url\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"3\n\x13GetAuthTokenRequest\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"6\n\x14GetAuthTokenResponse\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\r\n\x05token\x18\x01 \x01(\t\"4\n\x16\x45xtendAuthTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"\x19\n\x17\x45xtendAuthTokenResponse\"\'\n\x16RevokeAuthTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x19\n\x17RevokeAuthTokenResponse\";\n\x17SetGroupsForUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0e\n\x06groups\x18\x02 \x03(\t\"\x1a\n\x18SetGroupsForUserResponse\"B\n\x14ModifyMembersRequest\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0b\n\x03\x61\x64\x64\x18\x02 \x03(\t\x12\x0e\n\x06remove\x18\x03 \x03(\t\"\x17\n\x15ModifyMembersResponse\"$\n\x10GetGroupsRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"#\n\x11GetGroupsResponse\x12\x0e\n\x06groups\x18\x01 \x03(\t\" \n\x0fGetUsersRequest\x12\r\n\x05group\x18\x01 \x01(\t\"%\n\x10GetUsersResponse\x12\x11\n\tusernames\x18\x01 \x03(\t\"9\n\x19GetOneTimePasswordRequest\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"^\n\x1aGetOneTimePasswordResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x32\n\x0eotp_expiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x81\x01\n\x0fHashedAuthToken\x12\x14\n\x0chashed_token\x18\x01 \x01(\t\x12(\n\ntoken_info\x18\x02 \x01(\x0b\x32\x14.auth_1_12.TokenInfo\x12.\n\nexpiration\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1a\n\x18\x45xtractAuthTokensRequest\"G\n\x19\x45xtractAuthTokensResponse\x12*\n\x06tokens\x18\x01 \x03(\x0b\x32\x1a.auth_1_12.HashedAuthToken\"D\n\x17RestoreAuthTokenRequest\x12)\n\x05token\x18\x01 \x01(\x0b\x32\x1a.auth_1_12.HashedAuthToken\"\x1a\n\x18RestoreAuthTokenResponse*/\n\x0b\x43lusterRole\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05SUPER\x10\x01\x12\x06\n\x02\x46S\x10\x02*4\n\x05Scope\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06READER\x10\x01\x12\n\n\x06WRITER\x10\x02\x12\t\n\x05OWNER\x10\x03\x32\x94\x11\n\x03\x41PI\x12\x45\n\x08\x41\x63tivate\x12\x1a.auth_1_12.ActivateRequest\x1a\x1b.auth_1_12.ActivateResponse\"\x00\x12K\n\nDeactivate\x12\x1c.auth_1_12.DeactivateRequest\x1a\x1d.auth_1_12.DeactivateResponse\"\x00\x12]\n\x10GetConfiguration\x12\".auth_1_12.GetConfigurationRequest\x1a#.auth_1_12.GetConfigurationResponse\"\x00\x12]\n\x10SetConfiguration\x12\".auth_1_12.SetConfigurationRequest\x1a#.auth_1_12.SetConfigurationResponse\"\x00\x12H\n\tGetAdmins\x12\x1b.auth_1_12.GetAdminsRequest\x1a\x1c.auth_1_12.GetAdminsResponse\"\x00\x12Q\n\x0cModifyAdmins\x12\x1e.auth_1_12.ModifyAdminsRequest\x1a\x1f.auth_1_12.ModifyAdminsResponse\"\x00\x12o\n\x16GetClusterRoleBindings\x12(.auth_1_12.GetClusterRoleBindingsRequest\x1a).auth_1_12.GetClusterRoleBindingsResponse\"\x00\x12u\n\x18ModifyClusterRoleBinding\x12*.auth_1_12.ModifyClusterRoleBindingRequest\x1a+.auth_1_12.ModifyClusterRoleBindingResponse\"\x00\x12Q\n\x0c\x41uthenticate\x12\x1e.auth_1_12.AuthenticateRequest\x1a\x1f.auth_1_12.AuthenticateResponse\"\x00\x12H\n\tAuthorize\x12\x1b.auth_1_12.AuthorizeRequest\x1a\x1c.auth_1_12.AuthorizeResponse\"\x00\x12?\n\x06WhoAmI\x12\x18.auth_1_12.WhoAmIRequest\x1a\x19.auth_1_12.WhoAmIResponse\"\x00\x12\x45\n\x08GetScope\x12\x1a.auth_1_12.GetScopeRequest\x1a\x1b.auth_1_12.GetScopeResponse\"\x00\x12\x45\n\x08SetScope\x12\x1a.auth_1_12.SetScopeRequest\x1a\x1b.auth_1_12.SetScopeResponse\"\x00\x12?\n\x06GetACL\x12\x18.auth_1_12.GetACLRequest\x1a\x19.auth_1_12.GetACLResponse\"\x00\x12?\n\x06SetACL\x12\x18.auth_1_12.SetACLRequest\x1a\x19.auth_1_12.SetACLResponse\"\x00\x12Q\n\x0cGetOIDCLogin\x12\x1e.auth_1_12.GetOIDCLoginRequest\x1a\x1f.auth_1_12.GetOIDCLoginResponse\"\x00\x12Q\n\x0cGetAuthToken\x12\x1e.auth_1_12.GetAuthTokenRequest\x1a\x1f.auth_1_12.GetAuthTokenResponse\"\x00\x12Z\n\x0f\x45xtendAuthToken\x12!.auth_1_12.ExtendAuthTokenRequest\x1a\".auth_1_12.ExtendAuthTokenResponse\"\x00\x12Z\n\x0fRevokeAuthToken\x12!.auth_1_12.RevokeAuthTokenRequest\x1a\".auth_1_12.RevokeAuthTokenResponse\"\x00\x12]\n\x10SetGroupsForUser\x12\".auth_1_12.SetGroupsForUserRequest\x1a#.auth_1_12.SetGroupsForUserResponse\"\x00\x12T\n\rModifyMembers\x12\x1f.auth_1_12.ModifyMembersRequest\x1a .auth_1_12.ModifyMembersResponse\"\x00\x12H\n\tGetGroups\x12\x1b.auth_1_12.GetGroupsRequest\x1a\x1c.auth_1_12.GetGroupsResponse\"\x00\x12\x45\n\x08GetUsers\x12\x1a.auth_1_12.GetUsersRequest\x1a\x1b.auth_1_12.GetUsersResponse\"\x00\x12\x63\n\x12GetOneTimePassword\x12$.auth_1_12.GetOneTimePasswordRequest\x1a%.auth_1_12.GetOneTimePasswordResponse\"\x00\x12`\n\x11\x45xtractAuthTokens\x12#.auth_1_12.ExtractAuthTokensRequest\x1a$.auth_1_12.ExtractAuthTokensResponse\"\x00\x12]\n\x10RestoreAuthToken\x12\".auth_1_12.RestoreAuthTokenRequest\x1a#.auth_1_12.RestoreAuthTokenResponse\"\x00\x42<Z:github.com/pachyderm/pachyderm/src/client/admin/v1_12/authb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_CLUSTERROLE = _descriptor.EnumDescriptor(
  name='ClusterRole',
  full_name='auth_1_12.ClusterRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4390,
  serialized_end=4437,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERROLE)

ClusterRole = enum_type_wrapper.EnumTypeWrapper(_CLUSTERROLE)
_SCOPE = _descriptor.EnumDescriptor(
  name='Scope',
  full_name='auth_1_12.Scope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4439,
  serialized_end=4491,
)
_sym_db.RegisterEnumDescriptor(_SCOPE)

Scope = enum_type_wrapper.EnumTypeWrapper(_SCOPE)
UNDEFINED = 0
SUPER = 1
FS = 2
NONE = 0
READER = 1
WRITER = 2
OWNER = 3


_TOKENINFO_TOKENSOURCE = _descriptor.EnumDescriptor(
  name='TokenSource',
  full_name='auth_1_12.TokenInfo.TokenSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHENTICATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_TOKEN', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1886,
  serialized_end=1945,
)
_sym_db.RegisterEnumDescriptor(_TOKENINFO_TOKENSOURCE)


_ACTIVATEREQUEST = _descriptor.Descriptor(
  name='ActivateRequest',
  full_name='auth_1_12.ActivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.ActivateRequest.subject', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='github_token', full_name='auth_1_12.ActivateRequest.github_token', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_token', full_name='auth_1_12.ActivateRequest.root_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=158,
)


_ACTIVATERESPONSE = _descriptor.Descriptor(
  name='ActivateResponse',
  full_name='auth_1_12.ActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pach_token', full_name='auth_1_12.ActivateResponse.pach_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=198,
)


_DEACTIVATEREQUEST = _descriptor.Descriptor(
  name='DeactivateRequest',
  full_name='auth_1_12.DeactivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=219,
)


_DEACTIVATERESPONSE = _descriptor.Descriptor(
  name='DeactivateResponse',
  full_name='auth_1_12.DeactivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=241,
)


_IDPROVIDER_SAMLOPTIONS = _descriptor.Descriptor(
  name='SAMLOptions',
  full_name='auth_1_12.IDProvider.SAMLOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_url', full_name='auth_1_12.IDProvider.SAMLOptions.metadata_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_xml', full_name='auth_1_12.IDProvider.SAMLOptions.metadata_xml', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_attribute', full_name='auth_1_12.IDProvider.SAMLOptions.group_attribute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=526,
)

_IDPROVIDER_OIDCOPTIONS = _descriptor.Descriptor(
  name='OIDCOptions',
  full_name='auth_1_12.IDProvider.OIDCOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='auth_1_12.IDProvider.OIDCOptions.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='auth_1_12.IDProvider.OIDCOptions.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_secret', full_name='auth_1_12.IDProvider.OIDCOptions.client_secret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='auth_1_12.IDProvider.OIDCOptions.redirect_uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_scopes', full_name='auth_1_12.IDProvider.OIDCOptions.additional_scopes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_email_verified', full_name='auth_1_12.IDProvider.OIDCOptions.ignore_email_verified', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=680,
)

_IDPROVIDER_GITHUBOPTIONS = _descriptor.Descriptor(
  name='GitHubOptions',
  full_name='auth_1_12.IDProvider.GitHubOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=697,
)

_IDPROVIDER = _descriptor.Descriptor(
  name='IDProvider',
  full_name='auth_1_12.IDProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='auth_1_12.IDProvider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='auth_1_12.IDProvider.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saml', full_name='auth_1_12.IDProvider.saml', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oidc', full_name='auth_1_12.IDProvider.oidc', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='github', full_name='auth_1_12.IDProvider.github', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_IDPROVIDER_SAMLOPTIONS, _IDPROVIDER_OIDCOPTIONS, _IDPROVIDER_GITHUBOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=697,
)


_AUTHCONFIG_SAMLSERVICEOPTIONS = _descriptor.Descriptor(
  name='SAMLServiceOptions',
  full_name='auth_1_12.AuthConfig.SAMLServiceOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acs_url', full_name='auth_1_12.AuthConfig.SAMLServiceOptions.acs_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_url', full_name='auth_1_12.AuthConfig.SAMLServiceOptions.metadata_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dash_url', full_name='auth_1_12.AuthConfig.SAMLServiceOptions.dash_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_duration', full_name='auth_1_12.AuthConfig.SAMLServiceOptions.session_duration', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_logging', full_name='auth_1_12.AuthConfig.SAMLServiceOptions.debug_logging', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=982,
)

_AUTHCONFIG = _descriptor.Descriptor(
  name='AuthConfig',
  full_name='auth_1_12.AuthConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='live_config_version', full_name='auth_1_12.AuthConfig.live_config_version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_providers', full_name='auth_1_12.AuthConfig.id_providers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saml_svc_options', full_name='auth_1_12.AuthConfig.saml_svc_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AUTHCONFIG_SAMLSERVICEOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=982,
)


_GETCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetConfigurationRequest',
  full_name='auth_1_12.GetConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1009,
)


_GETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetConfigurationResponse',
  full_name='auth_1_12.GetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='auth_1_12.GetConfigurationResponse.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1083,
)


_SETCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='SetConfigurationRequest',
  full_name='auth_1_12.SetConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='auth_1_12.SetConfigurationRequest.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1156,
)


_SETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='SetConfigurationResponse',
  full_name='auth_1_12.SetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1184,
)


_CLUSTERROLES = _descriptor.Descriptor(
  name='ClusterRoles',
  full_name='auth_1_12.ClusterRoles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='auth_1_12.ClusterRoles.roles', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1239,
)


_GETCLUSTERROLEBINDINGSREQUEST = _descriptor.Descriptor(
  name='GetClusterRoleBindingsRequest',
  full_name='auth_1_12.GetClusterRoleBindingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1272,
)


_GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY = _descriptor.Descriptor(
  name='BindingsEntry',
  full_name='auth_1_12.GetClusterRoleBindingsResponse.BindingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_12.GetClusterRoleBindingsResponse.BindingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_12.GetClusterRoleBindingsResponse.BindingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1384,
  serialized_end=1456,
)

_GETCLUSTERROLEBINDINGSRESPONSE = _descriptor.Descriptor(
  name='GetClusterRoleBindingsResponse',
  full_name='auth_1_12.GetClusterRoleBindingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bindings', full_name='auth_1_12.GetClusterRoleBindingsResponse.bindings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1456,
)


_MODIFYCLUSTERROLEBINDINGREQUEST = _descriptor.Descriptor(
  name='ModifyClusterRoleBindingRequest',
  full_name='auth_1_12.ModifyClusterRoleBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='principal', full_name='auth_1_12.ModifyClusterRoleBindingRequest.principal', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='auth_1_12.ModifyClusterRoleBindingRequest.roles', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1458,
  serialized_end=1550,
)


_MODIFYCLUSTERROLEBINDINGRESPONSE = _descriptor.Descriptor(
  name='ModifyClusterRoleBindingResponse',
  full_name='auth_1_12.ModifyClusterRoleBindingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1586,
)


_GETADMINSREQUEST = _descriptor.Descriptor(
  name='GetAdminsRequest',
  full_name='auth_1_12.GetAdminsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1588,
  serialized_end=1606,
)


_GETADMINSRESPONSE = _descriptor.Descriptor(
  name='GetAdminsResponse',
  full_name='auth_1_12.GetAdminsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='admins', full_name='auth_1_12.GetAdminsResponse.admins', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1608,
  serialized_end=1643,
)


_MODIFYADMINSREQUEST = _descriptor.Descriptor(
  name='ModifyAdminsRequest',
  full_name='auth_1_12.ModifyAdminsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='add', full_name='auth_1_12.ModifyAdminsRequest.add', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='auth_1_12.ModifyAdminsRequest.remove', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1695,
)


_MODIFYADMINSRESPONSE = _descriptor.Descriptor(
  name='ModifyAdminsResponse',
  full_name='auth_1_12.ModifyAdminsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1697,
  serialized_end=1719,
)


_OTPINFO = _descriptor.Descriptor(
  name='OTPInfo',
  full_name='auth_1_12.OTPInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.OTPInfo.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_expiration', full_name='auth_1_12.OTPInfo.session_expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1721,
  serialized_end=1803,
)


_TOKENINFO = _descriptor.Descriptor(
  name='TokenInfo',
  full_name='auth_1_12.TokenInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.TokenInfo.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='auth_1_12.TokenInfo.source', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOKENINFO_TOKENSOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1945,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='auth_1_12.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='github_token', full_name='auth_1_12.AuthenticateRequest.github_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oidc_state', full_name='auth_1_12.AuthenticateRequest.oidc_state', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_time_password', full_name='auth_1_12.AuthenticateRequest.one_time_password', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_token', full_name='auth_1_12.AuthenticateRequest.id_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1947,
  serialized_end=2055,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='auth_1_12.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pach_token', full_name='auth_1_12.AuthenticateResponse.pach_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2057,
  serialized_end=2099,
)


_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='auth_1_12.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2116,
)


_WHOAMIRESPONSE = _descriptor.Descriptor(
  name='WhoAmIResponse',
  full_name='auth_1_12.WhoAmIResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.WhoAmIResponse.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='auth_1_12.WhoAmIResponse.is_admin', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_12.WhoAmIResponse.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_roles', full_name='auth_1_12.WhoAmIResponse.cluster_roles', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2118,
  serialized_end=2231,
)


_ACL_ENTRIESENTRY = _descriptor.Descriptor(
  name='EntriesEntry',
  full_name='auth_1_12.ACL.EntriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_12.ACL.EntriesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_12.ACL.EntriesEntry.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2350,
)

_ACL = _descriptor.Descriptor(
  name='ACL',
  full_name='auth_1_12.ACL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_12.ACL.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACL_ENTRIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2350,
)


_USERS_USERNAMESENTRY = _descriptor.Descriptor(
  name='UsernamesEntry',
  full_name='auth_1_12.Users.UsernamesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_12.Users.UsernamesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_12.Users.UsernamesEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2413,
  serialized_end=2461,
)

_USERS = _descriptor.Descriptor(
  name='Users',
  full_name='auth_1_12.Users',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usernames', full_name='auth_1_12.Users.usernames', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_USERS_USERNAMESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2352,
  serialized_end=2461,
)


_GROUPS_GROUPSENTRY = _descriptor.Descriptor(
  name='GroupsEntry',
  full_name='auth_1_12.Groups.GroupsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_12.Groups.GroupsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_12.Groups.GroupsEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2520,
  serialized_end=2565,
)

_GROUPS = _descriptor.Descriptor(
  name='Groups',
  full_name='auth_1_12.Groups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_12.Groups.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GROUPS_GROUPSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2463,
  serialized_end=2565,
)


_AUTHORIZEREQUEST = _descriptor.Descriptor(
  name='AuthorizeRequest',
  full_name='auth_1_12.AuthorizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_12.AuthorizeRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_12.AuthorizeRequest.scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2567,
  serialized_end=2632,
)


_AUTHORIZERESPONSE = _descriptor.Descriptor(
  name='AuthorizeResponse',
  full_name='auth_1_12.AuthorizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorized', full_name='auth_1_12.AuthorizeResponse.authorized', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2634,
  serialized_end=2673,
)


_GETSCOPEREQUEST = _descriptor.Descriptor(
  name='GetScopeRequest',
  full_name='auth_1_12.GetScopeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.GetScopeRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repos', full_name='auth_1_12.GetScopeRequest.repos', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2725,
)


_GETSCOPERESPONSE = _descriptor.Descriptor(
  name='GetScopeResponse',
  full_name='auth_1_12.GetScopeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scopes', full_name='auth_1_12.GetScopeResponse.scopes', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2779,
)


_SETSCOPEREQUEST = _descriptor.Descriptor(
  name='SetScopeRequest',
  full_name='auth_1_12.SetScopeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.SetScopeRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_12.SetScopeRequest.repo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_12.SetScopeRequest.scope', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2781,
  serialized_end=2863,
)


_SETSCOPERESPONSE = _descriptor.Descriptor(
  name='SetScopeResponse',
  full_name='auth_1_12.SetScopeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2865,
  serialized_end=2883,
)


_GETACLREQUEST = _descriptor.Descriptor(
  name='GetACLRequest',
  full_name='auth_1_12.GetACLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_12.GetACLRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=2914,
)


_ACLENTRY = _descriptor.Descriptor(
  name='ACLEntry',
  full_name='auth_1_12.ACLEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.ACLEntry.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_12.ACLEntry.scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2916,
  serialized_end=2977,
)


_GETACLRESPONSE = _descriptor.Descriptor(
  name='GetACLResponse',
  full_name='auth_1_12.GetACLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_12.GetACLResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='robot_entries', full_name='auth_1_12.GetACLResponse.robot_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3077,
)


_SETACLREQUEST = _descriptor.Descriptor(
  name='SetACLRequest',
  full_name='auth_1_12.SetACLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_12.SetACLRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_12.SetACLRequest.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3079,
  serialized_end=3146,
)


_SETACLRESPONSE = _descriptor.Descriptor(
  name='SetACLResponse',
  full_name='auth_1_12.SetACLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3148,
  serialized_end=3164,
)


_SESSIONINFO = _descriptor.Descriptor(
  name='SessionInfo',
  full_name='auth_1_12.SessionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='auth_1_12.SessionInfo.nonce', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='auth_1_12.SessionInfo.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_err', full_name='auth_1_12.SessionInfo.conversion_err', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3166,
  serialized_end=3233,
)


_GETOIDCLOGINREQUEST = _descriptor.Descriptor(
  name='GetOIDCLoginRequest',
  full_name='auth_1_12.GetOIDCLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3235,
  serialized_end=3256,
)


_GETOIDCLOGINRESPONSE = _descriptor.Descriptor(
  name='GetOIDCLoginResponse',
  full_name='auth_1_12.GetOIDCLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_url', full_name='auth_1_12.GetOIDCLoginResponse.login_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='auth_1_12.GetOIDCLoginResponse.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3258,
  serialized_end=3314,
)


_GETAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='GetAuthTokenRequest',
  full_name='auth_1_12.GetAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.GetAuthTokenRequest.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_12.GetAuthTokenRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3316,
  serialized_end=3367,
)


_GETAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='GetAuthTokenResponse',
  full_name='auth_1_12.GetAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.GetAuthTokenResponse.subject', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_12.GetAuthTokenResponse.token', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3369,
  serialized_end=3423,
)


_EXTENDAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='ExtendAuthTokenRequest',
  full_name='auth_1_12.ExtendAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_12.ExtendAuthTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_12.ExtendAuthTokenRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3425,
  serialized_end=3477,
)


_EXTENDAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='ExtendAuthTokenResponse',
  full_name='auth_1_12.ExtendAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3479,
  serialized_end=3504,
)


_REVOKEAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='RevokeAuthTokenRequest',
  full_name='auth_1_12.RevokeAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_12.RevokeAuthTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3506,
  serialized_end=3545,
)


_REVOKEAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='RevokeAuthTokenResponse',
  full_name='auth_1_12.RevokeAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3547,
  serialized_end=3572,
)


_SETGROUPSFORUSERREQUEST = _descriptor.Descriptor(
  name='SetGroupsForUserRequest',
  full_name='auth_1_12.SetGroupsForUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.SetGroupsForUserRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_12.SetGroupsForUserRequest.groups', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3574,
  serialized_end=3633,
)


_SETGROUPSFORUSERRESPONSE = _descriptor.Descriptor(
  name='SetGroupsForUserResponse',
  full_name='auth_1_12.SetGroupsForUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3635,
  serialized_end=3661,
)


_MODIFYMEMBERSREQUEST = _descriptor.Descriptor(
  name='ModifyMembersRequest',
  full_name='auth_1_12.ModifyMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='auth_1_12.ModifyMembersRequest.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add', full_name='auth_1_12.ModifyMembersRequest.add', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='auth_1_12.ModifyMembersRequest.remove', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3663,
  serialized_end=3729,
)


_MODIFYMEMBERSRESPONSE = _descriptor.Descriptor(
  name='ModifyMembersResponse',
  full_name='auth_1_12.ModifyMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3731,
  serialized_end=3754,
)


_GETGROUPSREQUEST = _descriptor.Descriptor(
  name='GetGroupsRequest',
  full_name='auth_1_12.GetGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_12.GetGroupsRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3756,
  serialized_end=3792,
)


_GETGROUPSRESPONSE = _descriptor.Descriptor(
  name='GetGroupsResponse',
  full_name='auth_1_12.GetGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_12.GetGroupsResponse.groups', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3794,
  serialized_end=3829,
)


_GETUSERSREQUEST = _descriptor.Descriptor(
  name='GetUsersRequest',
  full_name='auth_1_12.GetUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='auth_1_12.GetUsersRequest.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3831,
  serialized_end=3863,
)


_GETUSERSRESPONSE = _descriptor.Descriptor(
  name='GetUsersResponse',
  full_name='auth_1_12.GetUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usernames', full_name='auth_1_12.GetUsersResponse.usernames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3865,
  serialized_end=3902,
)


_GETONETIMEPASSWORDREQUEST = _descriptor.Descriptor(
  name='GetOneTimePasswordRequest',
  full_name='auth_1_12.GetOneTimePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_12.GetOneTimePasswordRequest.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_12.GetOneTimePasswordRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3904,
  serialized_end=3961,
)


_GETONETIMEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='GetOneTimePasswordResponse',
  full_name='auth_1_12.GetOneTimePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='auth_1_12.GetOneTimePasswordResponse.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otp_expiration', full_name='auth_1_12.GetOneTimePasswordResponse.otp_expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3963,
  serialized_end=4057,
)


_HASHEDAUTHTOKEN = _descriptor.Descriptor(
  name='HashedAuthToken',
  full_name='auth_1_12.HashedAuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hashed_token', full_name='auth_1_12.HashedAuthToken.hashed_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_info', full_name='auth_1_12.HashedAuthToken.token_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='auth_1_12.HashedAuthToken.expiration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4060,
  serialized_end=4189,
)


_EXTRACTAUTHTOKENSREQUEST = _descriptor.Descriptor(
  name='ExtractAuthTokensRequest',
  full_name='auth_1_12.ExtractAuthTokensRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4191,
  serialized_end=4217,
)


_EXTRACTAUTHTOKENSRESPONSE = _descriptor.Descriptor(
  name='ExtractAuthTokensResponse',
  full_name='auth_1_12.ExtractAuthTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='auth_1_12.ExtractAuthTokensResponse.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4219,
  serialized_end=4290,
)


_RESTOREAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='RestoreAuthTokenRequest',
  full_name='auth_1_12.RestoreAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_12.RestoreAuthTokenRequest.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4292,
  serialized_end=4360,
)


_RESTOREAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='RestoreAuthTokenResponse',
  full_name='auth_1_12.RestoreAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4362,
  serialized_end=4388,
)

_IDPROVIDER_SAMLOPTIONS.containing_type = _IDPROVIDER
_IDPROVIDER_OIDCOPTIONS.containing_type = _IDPROVIDER
_IDPROVIDER_GITHUBOPTIONS.containing_type = _IDPROVIDER
_IDPROVIDER.fields_by_name['saml'].message_type = _IDPROVIDER_SAMLOPTIONS
_IDPROVIDER.fields_by_name['oidc'].message_type = _IDPROVIDER_OIDCOPTIONS
_IDPROVIDER.fields_by_name['github'].message_type = _IDPROVIDER_GITHUBOPTIONS
_AUTHCONFIG_SAMLSERVICEOPTIONS.containing_type = _AUTHCONFIG
_AUTHCONFIG.fields_by_name['id_providers'].message_type = _IDPROVIDER
_AUTHCONFIG.fields_by_name['saml_svc_options'].message_type = _AUTHCONFIG_SAMLSERVICEOPTIONS
_GETCONFIGURATIONRESPONSE.fields_by_name['configuration'].message_type = _AUTHCONFIG
_SETCONFIGURATIONREQUEST.fields_by_name['configuration'].message_type = _AUTHCONFIG
_CLUSTERROLES.fields_by_name['roles'].enum_type = _CLUSTERROLE
_GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY.fields_by_name['value'].message_type = _CLUSTERROLES
_GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY.containing_type = _GETCLUSTERROLEBINDINGSRESPONSE
_GETCLUSTERROLEBINDINGSRESPONSE.fields_by_name['bindings'].message_type = _GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY
_MODIFYCLUSTERROLEBINDINGREQUEST.fields_by_name['roles'].message_type = _CLUSTERROLES
_OTPINFO.fields_by_name['session_expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOKENINFO.fields_by_name['source'].enum_type = _TOKENINFO_TOKENSOURCE
_TOKENINFO_TOKENSOURCE.containing_type = _TOKENINFO
_WHOAMIRESPONSE.fields_by_name['cluster_roles'].message_type = _CLUSTERROLES
_ACL_ENTRIESENTRY.fields_by_name['value'].enum_type = _SCOPE
_ACL_ENTRIESENTRY.containing_type = _ACL
_ACL.fields_by_name['entries'].message_type = _ACL_ENTRIESENTRY
_USERS_USERNAMESENTRY.containing_type = _USERS
_USERS.fields_by_name['usernames'].message_type = _USERS_USERNAMESENTRY
_GROUPS_GROUPSENTRY.containing_type = _GROUPS
_GROUPS.fields_by_name['groups'].message_type = _GROUPS_GROUPSENTRY
_AUTHORIZEREQUEST.fields_by_name['scope'].enum_type = _SCOPE
_GETSCOPERESPONSE.fields_by_name['scopes'].enum_type = _SCOPE
_SETSCOPEREQUEST.fields_by_name['scope'].enum_type = _SCOPE
_ACLENTRY.fields_by_name['scope'].enum_type = _SCOPE
_GETACLRESPONSE.fields_by_name['entries'].message_type = _ACLENTRY
_GETACLRESPONSE.fields_by_name['robot_entries'].message_type = _ACLENTRY
_SETACLREQUEST.fields_by_name['entries'].message_type = _ACLENTRY
_GETONETIMEPASSWORDRESPONSE.fields_by_name['otp_expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HASHEDAUTHTOKEN.fields_by_name['token_info'].message_type = _TOKENINFO
_HASHEDAUTHTOKEN.fields_by_name['expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXTRACTAUTHTOKENSRESPONSE.fields_by_name['tokens'].message_type = _HASHEDAUTHTOKEN
_RESTOREAUTHTOKENREQUEST.fields_by_name['token'].message_type = _HASHEDAUTHTOKEN
DESCRIPTOR.message_types_by_name['ActivateRequest'] = _ACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['ActivateResponse'] = _ACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['DeactivateRequest'] = _DEACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['DeactivateResponse'] = _DEACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['IDProvider'] = _IDPROVIDER
DESCRIPTOR.message_types_by_name['AuthConfig'] = _AUTHCONFIG
DESCRIPTOR.message_types_by_name['GetConfigurationRequest'] = _GETCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetConfigurationResponse'] = _GETCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigurationRequest'] = _SETCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['SetConfigurationResponse'] = _SETCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['ClusterRoles'] = _CLUSTERROLES
DESCRIPTOR.message_types_by_name['GetClusterRoleBindingsRequest'] = _GETCLUSTERROLEBINDINGSREQUEST
DESCRIPTOR.message_types_by_name['GetClusterRoleBindingsResponse'] = _GETCLUSTERROLEBINDINGSRESPONSE
DESCRIPTOR.message_types_by_name['ModifyClusterRoleBindingRequest'] = _MODIFYCLUSTERROLEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['ModifyClusterRoleBindingResponse'] = _MODIFYCLUSTERROLEBINDINGRESPONSE
DESCRIPTOR.message_types_by_name['GetAdminsRequest'] = _GETADMINSREQUEST
DESCRIPTOR.message_types_by_name['GetAdminsResponse'] = _GETADMINSRESPONSE
DESCRIPTOR.message_types_by_name['ModifyAdminsRequest'] = _MODIFYADMINSREQUEST
DESCRIPTOR.message_types_by_name['ModifyAdminsResponse'] = _MODIFYADMINSRESPONSE
DESCRIPTOR.message_types_by_name['OTPInfo'] = _OTPINFO
DESCRIPTOR.message_types_by_name['TokenInfo'] = _TOKENINFO
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
DESCRIPTOR.message_types_by_name['ACL'] = _ACL
DESCRIPTOR.message_types_by_name['Users'] = _USERS
DESCRIPTOR.message_types_by_name['Groups'] = _GROUPS
DESCRIPTOR.message_types_by_name['AuthorizeRequest'] = _AUTHORIZEREQUEST
DESCRIPTOR.message_types_by_name['AuthorizeResponse'] = _AUTHORIZERESPONSE
DESCRIPTOR.message_types_by_name['GetScopeRequest'] = _GETSCOPEREQUEST
DESCRIPTOR.message_types_by_name['GetScopeResponse'] = _GETSCOPERESPONSE
DESCRIPTOR.message_types_by_name['SetScopeRequest'] = _SETSCOPEREQUEST
DESCRIPTOR.message_types_by_name['SetScopeResponse'] = _SETSCOPERESPONSE
DESCRIPTOR.message_types_by_name['GetACLRequest'] = _GETACLREQUEST
DESCRIPTOR.message_types_by_name['ACLEntry'] = _ACLENTRY
DESCRIPTOR.message_types_by_name['GetACLResponse'] = _GETACLRESPONSE
DESCRIPTOR.message_types_by_name['SetACLRequest'] = _SETACLREQUEST
DESCRIPTOR.message_types_by_name['SetACLResponse'] = _SETACLRESPONSE
DESCRIPTOR.message_types_by_name['SessionInfo'] = _SESSIONINFO
DESCRIPTOR.message_types_by_name['GetOIDCLoginRequest'] = _GETOIDCLOGINREQUEST
DESCRIPTOR.message_types_by_name['GetOIDCLoginResponse'] = _GETOIDCLOGINRESPONSE
DESCRIPTOR.message_types_by_name['GetAuthTokenRequest'] = _GETAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetAuthTokenResponse'] = _GETAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['ExtendAuthTokenRequest'] = _EXTENDAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['ExtendAuthTokenResponse'] = _EXTENDAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['RevokeAuthTokenRequest'] = _REVOKEAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['RevokeAuthTokenResponse'] = _REVOKEAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['SetGroupsForUserRequest'] = _SETGROUPSFORUSERREQUEST
DESCRIPTOR.message_types_by_name['SetGroupsForUserResponse'] = _SETGROUPSFORUSERRESPONSE
DESCRIPTOR.message_types_by_name['ModifyMembersRequest'] = _MODIFYMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['ModifyMembersResponse'] = _MODIFYMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['GetGroupsRequest'] = _GETGROUPSREQUEST
DESCRIPTOR.message_types_by_name['GetGroupsResponse'] = _GETGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['GetUsersRequest'] = _GETUSERSREQUEST
DESCRIPTOR.message_types_by_name['GetUsersResponse'] = _GETUSERSRESPONSE
DESCRIPTOR.message_types_by_name['GetOneTimePasswordRequest'] = _GETONETIMEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['GetOneTimePasswordResponse'] = _GETONETIMEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['HashedAuthToken'] = _HASHEDAUTHTOKEN
DESCRIPTOR.message_types_by_name['ExtractAuthTokensRequest'] = _EXTRACTAUTHTOKENSREQUEST
DESCRIPTOR.message_types_by_name['ExtractAuthTokensResponse'] = _EXTRACTAUTHTOKENSRESPONSE
DESCRIPTOR.message_types_by_name['RestoreAuthTokenRequest'] = _RESTOREAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['RestoreAuthTokenResponse'] = _RESTOREAUTHTOKENRESPONSE
DESCRIPTOR.enum_types_by_name['ClusterRole'] = _CLUSTERROLE
DESCRIPTOR.enum_types_by_name['Scope'] = _SCOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivateRequest = _reflection.GeneratedProtocolMessageType('ActivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ActivateRequest)
  })
_sym_db.RegisterMessage(ActivateRequest)

ActivateResponse = _reflection.GeneratedProtocolMessageType('ActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ActivateResponse)
  })
_sym_db.RegisterMessage(ActivateResponse)

DeactivateRequest = _reflection.GeneratedProtocolMessageType('DeactivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.DeactivateRequest)
  })
_sym_db.RegisterMessage(DeactivateRequest)

DeactivateResponse = _reflection.GeneratedProtocolMessageType('DeactivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.DeactivateResponse)
  })
_sym_db.RegisterMessage(DeactivateResponse)

IDProvider = _reflection.GeneratedProtocolMessageType('IDProvider', (_message.Message,), {

  'SAMLOptions' : _reflection.GeneratedProtocolMessageType('SAMLOptions', (_message.Message,), {
    'DESCRIPTOR' : _IDPROVIDER_SAMLOPTIONS,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.IDProvider.SAMLOptions)
    })
  ,

  'OIDCOptions' : _reflection.GeneratedProtocolMessageType('OIDCOptions', (_message.Message,), {
    'DESCRIPTOR' : _IDPROVIDER_OIDCOPTIONS,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.IDProvider.OIDCOptions)
    })
  ,

  'GitHubOptions' : _reflection.GeneratedProtocolMessageType('GitHubOptions', (_message.Message,), {
    'DESCRIPTOR' : _IDPROVIDER_GITHUBOPTIONS,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.IDProvider.GitHubOptions)
    })
  ,
  'DESCRIPTOR' : _IDPROVIDER,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.IDProvider)
  })
_sym_db.RegisterMessage(IDProvider)
_sym_db.RegisterMessage(IDProvider.SAMLOptions)
_sym_db.RegisterMessage(IDProvider.OIDCOptions)
_sym_db.RegisterMessage(IDProvider.GitHubOptions)

AuthConfig = _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), {

  'SAMLServiceOptions' : _reflection.GeneratedProtocolMessageType('SAMLServiceOptions', (_message.Message,), {
    'DESCRIPTOR' : _AUTHCONFIG_SAMLSERVICEOPTIONS,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.AuthConfig.SAMLServiceOptions)
    })
  ,
  'DESCRIPTOR' : _AUTHCONFIG,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.AuthConfig)
  })
_sym_db.RegisterMessage(AuthConfig)
_sym_db.RegisterMessage(AuthConfig.SAMLServiceOptions)

GetConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetConfigurationRequest)
  })
_sym_db.RegisterMessage(GetConfigurationRequest)

GetConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetConfigurationResponse)
  })
_sym_db.RegisterMessage(GetConfigurationResponse)

SetConfigurationRequest = _reflection.GeneratedProtocolMessageType('SetConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGURATIONREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetConfigurationRequest)
  })
_sym_db.RegisterMessage(SetConfigurationRequest)

SetConfigurationResponse = _reflection.GeneratedProtocolMessageType('SetConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGURATIONRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetConfigurationResponse)
  })
_sym_db.RegisterMessage(SetConfigurationResponse)

ClusterRoles = _reflection.GeneratedProtocolMessageType('ClusterRoles', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLES,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ClusterRoles)
  })
_sym_db.RegisterMessage(ClusterRoles)

GetClusterRoleBindingsRequest = _reflection.GeneratedProtocolMessageType('GetClusterRoleBindingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERROLEBINDINGSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetClusterRoleBindingsRequest)
  })
_sym_db.RegisterMessage(GetClusterRoleBindingsRequest)

GetClusterRoleBindingsResponse = _reflection.GeneratedProtocolMessageType('GetClusterRoleBindingsResponse', (_message.Message,), {

  'BindingsEntry' : _reflection.GeneratedProtocolMessageType('BindingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.GetClusterRoleBindingsResponse.BindingsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCLUSTERROLEBINDINGSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetClusterRoleBindingsResponse)
  })
_sym_db.RegisterMessage(GetClusterRoleBindingsResponse)
_sym_db.RegisterMessage(GetClusterRoleBindingsResponse.BindingsEntry)

ModifyClusterRoleBindingRequest = _reflection.GeneratedProtocolMessageType('ModifyClusterRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYCLUSTERROLEBINDINGREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyClusterRoleBindingRequest)
  })
_sym_db.RegisterMessage(ModifyClusterRoleBindingRequest)

ModifyClusterRoleBindingResponse = _reflection.GeneratedProtocolMessageType('ModifyClusterRoleBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYCLUSTERROLEBINDINGRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyClusterRoleBindingResponse)
  })
_sym_db.RegisterMessage(ModifyClusterRoleBindingResponse)

GetAdminsRequest = _reflection.GeneratedProtocolMessageType('GetAdminsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETADMINSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetAdminsRequest)
  })
_sym_db.RegisterMessage(GetAdminsRequest)

GetAdminsResponse = _reflection.GeneratedProtocolMessageType('GetAdminsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETADMINSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetAdminsResponse)
  })
_sym_db.RegisterMessage(GetAdminsResponse)

ModifyAdminsRequest = _reflection.GeneratedProtocolMessageType('ModifyAdminsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYADMINSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyAdminsRequest)
  })
_sym_db.RegisterMessage(ModifyAdminsRequest)

ModifyAdminsResponse = _reflection.GeneratedProtocolMessageType('ModifyAdminsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYADMINSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyAdminsResponse)
  })
_sym_db.RegisterMessage(ModifyAdminsResponse)

OTPInfo = _reflection.GeneratedProtocolMessageType('OTPInfo', (_message.Message,), {
  'DESCRIPTOR' : _OTPINFO,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.OTPInfo)
  })
_sym_db.RegisterMessage(OTPInfo)

TokenInfo = _reflection.GeneratedProtocolMessageType('TokenInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOKENINFO,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.TokenInfo)
  })
_sym_db.RegisterMessage(TokenInfo)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType('WhoAmIResponse', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.WhoAmIResponse)
  })
_sym_db.RegisterMessage(WhoAmIResponse)

ACL = _reflection.GeneratedProtocolMessageType('ACL', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACL_ENTRIESENTRY,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.ACL.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _ACL,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ACL)
  })
_sym_db.RegisterMessage(ACL)
_sym_db.RegisterMessage(ACL.EntriesEntry)

Users = _reflection.GeneratedProtocolMessageType('Users', (_message.Message,), {

  'UsernamesEntry' : _reflection.GeneratedProtocolMessageType('UsernamesEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERS_USERNAMESENTRY,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.Users.UsernamesEntry)
    })
  ,
  'DESCRIPTOR' : _USERS,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.Users)
  })
_sym_db.RegisterMessage(Users)
_sym_db.RegisterMessage(Users.UsernamesEntry)

Groups = _reflection.GeneratedProtocolMessageType('Groups', (_message.Message,), {

  'GroupsEntry' : _reflection.GeneratedProtocolMessageType('GroupsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GROUPS_GROUPSENTRY,
    '__module__' : 'client.admin.v1_12.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_12.Groups.GroupsEntry)
    })
  ,
  'DESCRIPTOR' : _GROUPS,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.Groups)
  })
_sym_db.RegisterMessage(Groups)
_sym_db.RegisterMessage(Groups.GroupsEntry)

AuthorizeRequest = _reflection.GeneratedProtocolMessageType('AuthorizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.AuthorizeRequest)
  })
_sym_db.RegisterMessage(AuthorizeRequest)

AuthorizeResponse = _reflection.GeneratedProtocolMessageType('AuthorizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.AuthorizeResponse)
  })
_sym_db.RegisterMessage(AuthorizeResponse)

GetScopeRequest = _reflection.GeneratedProtocolMessageType('GetScopeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCOPEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetScopeRequest)
  })
_sym_db.RegisterMessage(GetScopeRequest)

GetScopeResponse = _reflection.GeneratedProtocolMessageType('GetScopeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCOPERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetScopeResponse)
  })
_sym_db.RegisterMessage(GetScopeResponse)

SetScopeRequest = _reflection.GeneratedProtocolMessageType('SetScopeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSCOPEREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetScopeRequest)
  })
_sym_db.RegisterMessage(SetScopeRequest)

SetScopeResponse = _reflection.GeneratedProtocolMessageType('SetScopeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETSCOPERESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetScopeResponse)
  })
_sym_db.RegisterMessage(SetScopeResponse)

GetACLRequest = _reflection.GeneratedProtocolMessageType('GetACLRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACLREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetACLRequest)
  })
_sym_db.RegisterMessage(GetACLRequest)

ACLEntry = _reflection.GeneratedProtocolMessageType('ACLEntry', (_message.Message,), {
  'DESCRIPTOR' : _ACLENTRY,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ACLEntry)
  })
_sym_db.RegisterMessage(ACLEntry)

GetACLResponse = _reflection.GeneratedProtocolMessageType('GetACLResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACLRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetACLResponse)
  })
_sym_db.RegisterMessage(GetACLResponse)

SetACLRequest = _reflection.GeneratedProtocolMessageType('SetACLRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETACLREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetACLRequest)
  })
_sym_db.RegisterMessage(SetACLRequest)

SetACLResponse = _reflection.GeneratedProtocolMessageType('SetACLResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETACLRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetACLResponse)
  })
_sym_db.RegisterMessage(SetACLResponse)

SessionInfo = _reflection.GeneratedProtocolMessageType('SessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONINFO,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SessionInfo)
  })
_sym_db.RegisterMessage(SessionInfo)

GetOIDCLoginRequest = _reflection.GeneratedProtocolMessageType('GetOIDCLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCLOGINREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetOIDCLoginRequest)
  })
_sym_db.RegisterMessage(GetOIDCLoginRequest)

GetOIDCLoginResponse = _reflection.GeneratedProtocolMessageType('GetOIDCLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOIDCLOGINRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetOIDCLoginResponse)
  })
_sym_db.RegisterMessage(GetOIDCLoginResponse)

GetAuthTokenRequest = _reflection.GeneratedProtocolMessageType('GetAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetAuthTokenRequest)
  })
_sym_db.RegisterMessage(GetAuthTokenRequest)

GetAuthTokenResponse = _reflection.GeneratedProtocolMessageType('GetAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetAuthTokenResponse)
  })
_sym_db.RegisterMessage(GetAuthTokenResponse)

ExtendAuthTokenRequest = _reflection.GeneratedProtocolMessageType('ExtendAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ExtendAuthTokenRequest)
  })
_sym_db.RegisterMessage(ExtendAuthTokenRequest)

ExtendAuthTokenResponse = _reflection.GeneratedProtocolMessageType('ExtendAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ExtendAuthTokenResponse)
  })
_sym_db.RegisterMessage(ExtendAuthTokenResponse)

RevokeAuthTokenRequest = _reflection.GeneratedProtocolMessageType('RevokeAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.RevokeAuthTokenRequest)
  })
_sym_db.RegisterMessage(RevokeAuthTokenRequest)

RevokeAuthTokenResponse = _reflection.GeneratedProtocolMessageType('RevokeAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.RevokeAuthTokenResponse)
  })
_sym_db.RegisterMessage(RevokeAuthTokenResponse)

SetGroupsForUserRequest = _reflection.GeneratedProtocolMessageType('SetGroupsForUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETGROUPSFORUSERREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetGroupsForUserRequest)
  })
_sym_db.RegisterMessage(SetGroupsForUserRequest)

SetGroupsForUserResponse = _reflection.GeneratedProtocolMessageType('SetGroupsForUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETGROUPSFORUSERRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.SetGroupsForUserResponse)
  })
_sym_db.RegisterMessage(SetGroupsForUserResponse)

ModifyMembersRequest = _reflection.GeneratedProtocolMessageType('ModifyMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYMEMBERSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyMembersRequest)
  })
_sym_db.RegisterMessage(ModifyMembersRequest)

ModifyMembersResponse = _reflection.GeneratedProtocolMessageType('ModifyMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYMEMBERSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ModifyMembersResponse)
  })
_sym_db.RegisterMessage(ModifyMembersResponse)

GetGroupsRequest = _reflection.GeneratedProtocolMessageType('GetGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetGroupsRequest)
  })
_sym_db.RegisterMessage(GetGroupsRequest)

GetGroupsResponse = _reflection.GeneratedProtocolMessageType('GetGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetGroupsResponse)
  })
_sym_db.RegisterMessage(GetGroupsResponse)

GetUsersRequest = _reflection.GeneratedProtocolMessageType('GetUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetUsersRequest)
  })
_sym_db.RegisterMessage(GetUsersRequest)

GetUsersResponse = _reflection.GeneratedProtocolMessageType('GetUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetUsersResponse)
  })
_sym_db.RegisterMessage(GetUsersResponse)

GetOneTimePasswordRequest = _reflection.GeneratedProtocolMessageType('GetOneTimePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETONETIMEPASSWORDREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetOneTimePasswordRequest)
  })
_sym_db.RegisterMessage(GetOneTimePasswordRequest)

GetOneTimePasswordResponse = _reflection.GeneratedProtocolMessageType('GetOneTimePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONETIMEPASSWORDRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.GetOneTimePasswordResponse)
  })
_sym_db.RegisterMessage(GetOneTimePasswordResponse)

HashedAuthToken = _reflection.GeneratedProtocolMessageType('HashedAuthToken', (_message.Message,), {
  'DESCRIPTOR' : _HASHEDAUTHTOKEN,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.HashedAuthToken)
  })
_sym_db.RegisterMessage(HashedAuthToken)

ExtractAuthTokensRequest = _reflection.GeneratedProtocolMessageType('ExtractAuthTokensRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTAUTHTOKENSREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ExtractAuthTokensRequest)
  })
_sym_db.RegisterMessage(ExtractAuthTokensRequest)

ExtractAuthTokensResponse = _reflection.GeneratedProtocolMessageType('ExtractAuthTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTAUTHTOKENSRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.ExtractAuthTokensResponse)
  })
_sym_db.RegisterMessage(ExtractAuthTokensResponse)

RestoreAuthTokenRequest = _reflection.GeneratedProtocolMessageType('RestoreAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.RestoreAuthTokenRequest)
  })
_sym_db.RegisterMessage(RestoreAuthTokenRequest)

RestoreAuthTokenResponse = _reflection.GeneratedProtocolMessageType('RestoreAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_12.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_12.RestoreAuthTokenResponse)
  })
_sym_db.RegisterMessage(RestoreAuthTokenResponse)


DESCRIPTOR._options = None
_GETCLUSTERROLEBINDINGSRESPONSE_BINDINGSENTRY._options = None
_ACL_ENTRIESENTRY._options = None
_USERS_USERNAMESENTRY._options = None
_GROUPS_GROUPSENTRY._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='auth_1_12.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=4494,
  serialized_end=6690,
  methods=[
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='auth_1_12.API.Activate',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEREQUEST,
    output_type=_ACTIVATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='auth_1_12.API.Deactivate',
    index=1,
    containing_service=None,
    input_type=_DEACTIVATEREQUEST,
    output_type=_DEACTIVATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfiguration',
    full_name='auth_1_12.API.GetConfiguration',
    index=2,
    containing_service=None,
    input_type=_GETCONFIGURATIONREQUEST,
    output_type=_GETCONFIGURATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfiguration',
    full_name='auth_1_12.API.SetConfiguration',
    index=3,
    containing_service=None,
    input_type=_SETCONFIGURATIONREQUEST,
    output_type=_SETCONFIGURATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAdmins',
    full_name='auth_1_12.API.GetAdmins',
    index=4,
    containing_service=None,
    input_type=_GETADMINSREQUEST,
    output_type=_GETADMINSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyAdmins',
    full_name='auth_1_12.API.ModifyAdmins',
    index=5,
    containing_service=None,
    input_type=_MODIFYADMINSREQUEST,
    output_type=_MODIFYADMINSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetClusterRoleBindings',
    full_name='auth_1_12.API.GetClusterRoleBindings',
    index=6,
    containing_service=None,
    input_type=_GETCLUSTERROLEBINDINGSREQUEST,
    output_type=_GETCLUSTERROLEBINDINGSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyClusterRoleBinding',
    full_name='auth_1_12.API.ModifyClusterRoleBinding',
    index=7,
    containing_service=None,
    input_type=_MODIFYCLUSTERROLEBINDINGREQUEST,
    output_type=_MODIFYCLUSTERROLEBINDINGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='auth_1_12.API.Authenticate',
    index=8,
    containing_service=None,
    input_type=_AUTHENTICATEREQUEST,
    output_type=_AUTHENTICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Authorize',
    full_name='auth_1_12.API.Authorize',
    index=9,
    containing_service=None,
    input_type=_AUTHORIZEREQUEST,
    output_type=_AUTHORIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WhoAmI',
    full_name='auth_1_12.API.WhoAmI',
    index=10,
    containing_service=None,
    input_type=_WHOAMIREQUEST,
    output_type=_WHOAMIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetScope',
    full_name='auth_1_12.API.GetScope',
    index=11,
    containing_service=None,
    input_type=_GETSCOPEREQUEST,
    output_type=_GETSCOPERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetScope',
    full_name='auth_1_12.API.SetScope',
    index=12,
    containing_service=None,
    input_type=_SETSCOPEREQUEST,
    output_type=_SETSCOPERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetACL',
    full_name='auth_1_12.API.GetACL',
    index=13,
    containing_service=None,
    input_type=_GETACLREQUEST,
    output_type=_GETACLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetACL',
    full_name='auth_1_12.API.SetACL',
    index=14,
    containing_service=None,
    input_type=_SETACLREQUEST,
    output_type=_SETACLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOIDCLogin',
    full_name='auth_1_12.API.GetOIDCLogin',
    index=15,
    containing_service=None,
    input_type=_GETOIDCLOGINREQUEST,
    output_type=_GETOIDCLOGINRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthToken',
    full_name='auth_1_12.API.GetAuthToken',
    index=16,
    containing_service=None,
    input_type=_GETAUTHTOKENREQUEST,
    output_type=_GETAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtendAuthToken',
    full_name='auth_1_12.API.ExtendAuthToken',
    index=17,
    containing_service=None,
    input_type=_EXTENDAUTHTOKENREQUEST,
    output_type=_EXTENDAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeAuthToken',
    full_name='auth_1_12.API.RevokeAuthToken',
    index=18,
    containing_service=None,
    input_type=_REVOKEAUTHTOKENREQUEST,
    output_type=_REVOKEAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetGroupsForUser',
    full_name='auth_1_12.API.SetGroupsForUser',
    index=19,
    containing_service=None,
    input_type=_SETGROUPSFORUSERREQUEST,
    output_type=_SETGROUPSFORUSERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyMembers',
    full_name='auth_1_12.API.ModifyMembers',
    index=20,
    containing_service=None,
    input_type=_MODIFYMEMBERSREQUEST,
    output_type=_MODIFYMEMBERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroups',
    full_name='auth_1_12.API.GetGroups',
    index=21,
    containing_service=None,
    input_type=_GETGROUPSREQUEST,
    output_type=_GETGROUPSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUsers',
    full_name='auth_1_12.API.GetUsers',
    index=22,
    containing_service=None,
    input_type=_GETUSERSREQUEST,
    output_type=_GETUSERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOneTimePassword',
    full_name='auth_1_12.API.GetOneTimePassword',
    index=23,
    containing_service=None,
    input_type=_GETONETIMEPASSWORDREQUEST,
    output_type=_GETONETIMEPASSWORDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtractAuthTokens',
    full_name='auth_1_12.API.ExtractAuthTokens',
    index=24,
    containing_service=None,
    input_type=_EXTRACTAUTHTOKENSREQUEST,
    output_type=_EXTRACTAUTHTOKENSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RestoreAuthToken',
    full_name='auth_1_12.API.RestoreAuthToken',
    index=25,
    containing_service=None,
    input_type=_RESTOREAUTHTOKENREQUEST,
    output_type=_RESTOREAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
